@@ -1,4 +1,4 @@
-from .sqlee import Sqlee
+from .sqlee import SqleeRepository
 from .config import __version__
 
 __name__ = "sqlee"
@@ -10,4 +10,4 @@ __author__ = "Entropy <fu050409@163.com>"
 __incantation__ = "嗡嘛呢叭咪吽"
 
 def connect(token=None, repo=None, owner=None):
-    return Sqlee(access_token=token, repo=repo, owner=owner)
+    return SqleeRepository(access_token=token, repo=repo, owner=owner)
