@@ -6,17 +6,18 @@ import argparse, shlex, platform
 import importlib
 
 from prompt_toolkit import prompt
+from prompt_toolkit.output.win32 import NoConsoleScreenBufferError
 from requests import get, post, put, delete
 
 if __name__ == "__main__":
     from utils import gitee
     from utils.backend import URL, SqleeData, SqleeColumn, SqleeTable
+    from utils.exceptions import RepositoryNotFoundError, TableNotFoundError
     from config import __version__
 else:
     from .utils import gitee
     from .utils.backend import URL, SqleeData, SqleeColumn, SqleeTable
     from .config import __version__
-from prompt_toolkit.output.win32 import NoConsoleScreenBufferError
 
 class termios:
     class error(RuntimeError):
@@ -33,7 +34,7 @@ class objects:
     def get(self, name=None):
         if name in self.obj.repo.list_folder(path=""):
             return SqleeTable(name=name, repo=self.obj.repo)
-        raise ValueError("目标表不存在.")
+        raise TableNotFoundError(name)
 
     def create(self, name=None, namespace=None):
         return self.obj.create_table(name=name, namespace=namespace)
@@ -48,7 +49,7 @@ class objects:
     def count(self):
         return len(self.obj.repo.list_folder(path="", detail=True))
 
-class Sqlee:
+class SqleeRepository:
     access_token = None
     repo = None
     owner = None
