@@ -1,29 +1,12 @@
 #coding: utf-8
 if __name__ == "__main__":
     from gitee import GiteeRepo
+    from urlparse import URL
 else:
     from .gitee import GiteeRepo
+    from .urlparse import URL
 
-import json
-
-class URL:
-    url = "https://gitee.com/"
-    def __init__(self, url=None):
-        self.url = url if url != None else self.url
-        self.url = self.url if self.url[-1] == "/" else self.url + "/"
-        
-    def __add__(self, value):
-        value = str(value)
-        value = value if value[-1] == "/" else value + "/"
-        return URL(url=self.url + value)
-        
-    def __truediv__(self, value):
-        value = str(value)
-        value = value if value[-1] == "/" else value + "/"
-        return URL(url=self.url + value)
-
-    def __str__(self):
-        return self.url
+import json, warnings
 
 def model_to_data(model=None):
     return tuple([i.data if hasattr(i, "data") else i for i in model])
@@ -187,7 +170,9 @@ class SqleeColumn:
                 )
 
         if len(self.datas) != len(self.namespace):
-            print("数据错误: 捕获到的数据与命名域不符:\n\t命名域: %s\n\t数据: %s." % (self.namespace, model_to_data(self.datas)))
+            wanings.warn(
+                ColumnDataDoesNotFit
+                )
         self.datas = tuple(self.datas)
         return self.datas
 
@@ -222,7 +207,7 @@ class SqleeTable:
             if column.id == id:
                 return column
         else:
-            raise ValueError("目标栏不存在.")
+            raise ColumnNotFoundError(id)
 
     def insert(self, datas=None):
         return self.objects.create(datas=datas)
