@@ -4,7 +4,7 @@
    版本: 1.0
 """
 from urllib.parse import urlencode
-
+from .exceptions import RepositoryNotFoundError
 import requests
 import json
 import base64
@@ -19,7 +19,7 @@ class GiteeRepo:
         self.repo = repo
         self.url = "https://gitee.com/" + user + "/" + repo + "/"
         if requests.get(url=self.url).status_code == 404:
-            raise NameError("仓库 %s 不存在." % (self.repo))
+            raise RepositoryNotFoundError(repo)
 
         self.types = {}
         self.types["int"] = int
